@@ -147,6 +147,20 @@ public abstract class Inspector {
     /////////////////////////////////////////////////////////////////
     // utility method
 
+    // null differ //////////////////////////////////////////////////
+
+    /**
+     * オブジェクトが等しい(いづれかがnullではない)ことを表明する。
+     * 
+     * @param expected 期待する値
+     * @param actual 実際の値
+     */
+    public static void assertNullEquals(Object expected, Object actual) {
+        ObjectBackTrace trace = new ObjectBackTrace();
+        assertNullEquals(expected, actual, trace);
+        trace.clear();
+    }
+
     /**
      * オブジェクトが等しい(いづれかがnullではない)ことを表明する。
      * 
@@ -163,6 +177,20 @@ public abstract class Inspector {
         }
     }
 
+    // class differ /////////////////////////////////////////////////
+
+    /**
+     * クラスが等しいことを表明する。
+     * 
+     * @param expected 期待する値
+     * @param actual 実際の値
+     */
+    public static void assertClassEquals(Object expected, Object actual) {
+        ObjectBackTrace trace = new ObjectBackTrace();
+        assertClassEquals(expected, actual, trace, true);
+        trace.clear();
+    }
+
     /**
      * クラスが等しいことを表明する。
      * 
@@ -172,8 +200,21 @@ public abstract class Inspector {
      */
     protected static void assertClassEquals(Object expected, Object actual,
             ObjectBackTrace trace) {
+        assertClassEquals(expected, actual, trace, Config.isInspectionClass());
+    }
+
+    /**
+     * クラスが等しいことを表明する。
+     * 
+     * @param expected 期待する値
+     * @param actual 実際の値
+     * @param trace バックトレース
+     * @param exec 検査する場合はtrue
+     */
+    protected static void assertClassEquals(Object expected, Object actual,
+            ObjectBackTrace trace, boolean exec) {
         // クラスを検査しない場合は処理を抜ける。
-        if (!Config.isInspectionClass()) {
+        if (!exec) {
             return;
         }
 
@@ -187,6 +228,20 @@ public abstract class Inspector {
         }
     }
 
+    // size differ //////////////////////////////////////////////////
+
+    /**
+     * サイズが等しいことを表明する。
+     * 
+     * @param expected 期待する値
+     * @param actual 実際の値
+     */
+    public static void assertSizeEquals(int expected, int actual) {
+        ObjectBackTrace trace = new ObjectBackTrace();
+        assertSizeEquals("size differ", expected, actual, trace, true);
+        trace.clear();
+    }
+
     /**
      * サイズが等しいことを表明する。
      * 
@@ -209,8 +264,23 @@ public abstract class Inspector {
      */
     protected static void assertSizeEquals(String message, int expected,
             int actual, ObjectBackTrace trace) {
+        assertSizeEquals(message, expected, actual, trace, Config
+                .isInspectionSize());
+    }
+
+    /**
+     * サイズが等しいことを表明する。
+     * 
+     * @param message メッセージ
+     * @param expected 期待する値
+     * @param actual 実際の値
+     * @param trace バックトレース
+     * @param exec 検査する場合はtrue
+     */
+    protected static void assertSizeEquals(String message, int expected,
+            int actual, ObjectBackTrace trace, boolean exec) {
         // サイズを検査しない場合は処理を抜ける。
-        if (!Config.isInspectionSize()) {
+        if (!exec) {
             return;
         }
 
@@ -221,6 +291,32 @@ public abstract class Inspector {
         }
     }
 
+    // keyset differ ////////////////////////////////////////////////
+
+    /**
+     * キーセットが等しいことを表明する。
+     * 
+     * @param expected 期待する値
+     * @param actual 実際の値
+     */
+    public static void assertKeySetEquals(Set expected, Set actual) {
+        assertKeySetEquals(expected, actual, true);
+    }
+
+    /**
+     * キーセットが等しいことを表明する。
+     * 
+     * @param expected 期待する値
+     * @param actual 実際の値
+     * @param strictly 厳密に精査する場合はtrue
+     */
+    public static void assertKeySetEquals(Set expected, Set actual,
+            boolean strictly) {
+        ObjectBackTrace trace = new ObjectBackTrace();
+        assertKeySetEquals("key set differ", expected, actual, trace, strictly);
+        trace.clear();
+    }
+
     /**
      * キーセットが等しいことを表明する。
      * 
@@ -243,6 +339,21 @@ public abstract class Inspector {
      */
     protected static void assertKeySetEquals(String message, Set expected,
             Set actual, ObjectBackTrace trace) {
+        assertKeySetEquals(message, expected, actual, trace, Config
+                .isInspectionKeySetStrictly());
+    }
+
+    /**
+     * キーセットが等しいことを表明する。
+     * 
+     * @param message メッセージ
+     * @param expected 期待する値
+     * @param actual 実際の値
+     * @param trace バックトレース
+     * @param strictly 厳密に精査する場合はtrue
+     */
+    protected static void assertKeySetEquals(String message, Set expected,
+            Set actual, ObjectBackTrace trace, boolean strictly) {
         // イテレータを取得。
         Iterator expectedIte = expected.iterator();
         Iterator actualIte = actual.iterator();
@@ -257,7 +368,7 @@ public abstract class Inspector {
         }
 
         // 厳密に検査する場合、キーセットが完全に一致するか検査。
-        if (Config.isInspectionKeySetStrictly()) {
+        if (strictly) {
             while (actualIte.hasNext()) {
                 Object actualElement = actualIte.next();
 
@@ -268,6 +379,8 @@ public abstract class Inspector {
         }
     }
 
+    // regex differ /////////////////////////////////////////////////
+
     /**
      * 正規表現書式のエスケープを解除する。
      * 
@@ -324,6 +437,18 @@ public abstract class Inspector {
         return true;
     }
 
+    /**
+     * 文字列が正規表現にマッチすることを表明する。
+     * 
+     * @param regex 期待する正規表現
+     * @param actual 実際の値
+     */
+    public static void assertRegexEquals(String regex, String actual) {
+        ObjectBackTrace trace = new ObjectBackTrace();
+        assertRegexEquals(regex, actual, trace);
+        trace.clear();
+    }
+
     /**
      * 文字列が正規表現にマッチすることを表明する。
      * 
@@ -362,6 +487,8 @@ public abstract class Inspector {
         }
     }
 
+    /////////////////////////////////////////////////////////////////
+
     /**
      * 例外を投げる。
      * 
