@@ -55,9 +55,9 @@ public class ObjectUtils {
         // オブジェクトを生成。
         if (value != null) {
             return getInstance(type, new Class[] { String.class },
-                    new Object[] { value });
+                    new Object[] { value }, false);
         } else {
-            return getInstance(type, new Class[0], new Object[0]);
+            return getInstance(type, new Class[0], new Object[0], false);
         }
     }
 
@@ -87,9 +87,9 @@ public class ObjectUtils {
         // オブジェクトを生成。
         if (value != null) {
             return getInstance(type, new Class[] { String.class },
-                    new Object[] { value });
+                    new Object[] { value }, false);
         } else {
-            return getInstance(type, new Class[0], new Object[0]);
+            return getInstance(type, new Class[0], new Object[0], false);
         }
     }
 
@@ -193,12 +193,13 @@ public class ObjectUtils {
      * @param type クラス名
      * @param classes コンストラクタの引数の型
      * @param arguments コンストラクタの引数
+     * @param search コンストラクタの検索をする場合はtrue
      * @return インスタンス
      */
     public static Object getInstance(String type, Class[] classes,
-            Object[] arguments) {
+            Object[] arguments, boolean search) {
         Class clazz = getClass(type);
-        return getInstance(clazz, classes, arguments);
+        return getInstance(clazz, classes, arguments, search);
     }
 
     /**
@@ -207,12 +208,13 @@ public class ObjectUtils {
      * @param clazz クラス
      * @param classes コンストラクタの引数の型
      * @param arguments コンストラクタの引数
+     * @param search コンストラクタの検索をする場合はtrue
      * @return インスタンス
      */
     public static Object getInstance(Class clazz, Class[] classes,
-            Object[] arguments) {
+            Object[] arguments, boolean search) {
         try {
-            Constructor constructor = getConstructor(clazz, classes);
+            Constructor constructor = getConstructor(clazz, classes, search);
             constructor.setAccessible(true);
             return constructor.newInstance(arguments);
         } catch (SecurityException e) {
@@ -233,12 +235,16 @@ public class ObjectUtils {
      * 
      * @param clazz クラス
      * @param types パラメータの型
+     * @param search コンストラクタの検索をする場合はtrue
      * @return コンストラクタ
      */
-    public static Constructor getConstructor(Class clazz, Class[] types) {
+    public static Constructor getConstructor(Class clazz, Class[] types,
+            boolean search) {
         try {
             if (types == null || types.length < 1) {
                 return clazz.getConstructor(new Class[0]);
+            } else if (!search) {
+                return clazz.getConstructor(types);
             }
 
             Constructor constructor = null;
@@ -695,15 +701,17 @@ public class ObjectUtils {
      * @param object オブジェクト
      * @param name メソッド名
      * @param classes 引数のクラス
+     * @param search メソッドの検索をする場合はtrue
      * @return メソッド
      */
-    public static Method getMethod(Object object, String name, Class[] classes) {
+    public static Method getMethod(Object object, String name, Class[] classes,
+            boolean search) {
         if (object == null) {
             throw new BodyBuilderException("object that '" + name
                     + "' defined is null.");
         }
 
-        return getMethod(object.getClass(), name, classes);
+        return getMethod(object.getClass(), name, classes, search);
     }
 
     /**
@@ -711,12 +719,16 @@ public class ObjectUtils {
      * 
      * @param clazz クラス
      * @param types パラメータの型
+     * @param search メソッドの検索をする場合はtrue
      * @return メソッド
      */
-    public static Method getMethod(Class clazz, String name, Class[] types) {
+    public static Method getMethod(Class clazz, String name, Class[] types,
+            boolean search) {
         try {
             if (types == null || types.length < 1) {
                 return clazz.getMethod(name, new Class[0]);
+            } else if (!search) {
+                return clazz.getMethod(name, types);
             }
 
             Method method = null;
@@ -777,11 +789,13 @@ public class ObjectUtils {
      * @param name メソッド名
      * @param classes 引数のクラス
      * @param arguments 引数
+     * @param search メソッドの検索をする場合はtrue
      * @return メソッドの戻り値
      */
     public static Object invokeMethod(String type, String name,
-            Class[] classes, Object[] arguments) {
-        return invokeMethod(getClass(type), null, name, classes, arguments);
+            Class[] classes, Object[] arguments, boolean search) {
+        return invokeMethod(getClass(type), null, name, classes, arguments,
+                search);
     }
 
     /**
@@ -791,16 +805,18 @@ public class ObjectUtils {
      * @param name メソッド名
      * @param classes 引数のクラス
      * @param arguments 引数
+     * @param search メソッドの検索をする場合はtrue
      * @return メソッドの戻り値
      */
     public static Object invokeMethod(Object object, String name,
-            Class[] classes, Object[] arguments) {
+            Class[] classes, Object[] arguments, boolean search) {
         if (object == null) {
             throw new BodyBuilderException("object that '" + name
                     + "' defined is null.");
         }
 
-        return invokeMethod(object.getClass(), object, name, classes, arguments);
+        return invokeMethod(object.getClass(), object, name, classes,
+                arguments, search);
     }
 
     /**
@@ -811,11 +827,12 @@ public class ObjectUtils {
      * @param name メソッド名
      * @param classes 引数のクラス
      * @param arguments 引数
+     * @param search メソッドの検索をする場合はtrue
      * @return メソッドの戻り値
      */
     public static Object invokeMethod(Class clazz, Object object, String name,
-            Class[] classes, Object[] arguments) {
-        Method method = getMethod(clazz, name, classes);
+            Class[] classes, Object[] arguments, boolean search) {
+        Method method = getMethod(clazz, name, classes, search);
         return invokeMethod(clazz, object, method, arguments);
     }
 
@@ -944,6 +961,8 @@ public class ObjectUtils {
                 Class wrapper = getPrimitiveWrapperClass(type);
                 return wrapper.getName().equals(clazz.getName());
             }
+        } else if (Object.class.getName().equals(type)) {
+            return true;
         } else {
             List classes = getClassNames(clazz);
             return classes.contains(type);
